"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const core_1 = require("@tracerbench/core");
const flags_1 = require("../helpers/flags");
const path = require("path");
const fs = require("fs-extra");
class CreateArchive extends command_1.Command {
    async run() {
        const { flags } = this.parse(CreateArchive);
        const { browserArgs, url, tbResultsFolder } = flags;
        const archiveOutput = path.join(tbResultsFolder, 'trace.har');
        const cookiesJSON = path.join(tbResultsFolder, 'cookies.json');
        let cookies;
        let harArchive;
        if (!fs.existsSync(tbResultsFolder)) {
            fs.mkdirSync(tbResultsFolder);
        }
        [cookies, harArchive] = await core_1.harTrace(url, browserArgs);
        fs.writeFileSync(cookiesJSON, JSON.stringify(cookies));
        fs.writeFileSync(archiveOutput, JSON.stringify(harArchive));
        this.log(`Captured ${harArchive.log.entries.length} request responses in har file.`);
        return this.log(`HAR & cookies.json successfully generated from ${url} and available here: ${archiveOutput} and ${cookiesJSON}`);
    }
}
exports.default = CreateArchive;
CreateArchive.description = 'Creates an automated HAR file from a URL.';
CreateArchive.flags = {
    browserArgs: flags_1.browserArgs({ required: true }),
    tbResultsFolder: flags_1.tbResultsFolder({ required: true }),
    url: flags_1.url({ required: true })
};
//# sourceMappingURL=create-archive.js.map