"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const fs = require("fs-extra");
const path = require("path");
const flags_1 = require("../helpers/flags");
const utils_1 = require("../helpers/utils");
class MarkerTimings extends command_1.Command {
    async run() {
        const { flags } = this.parse(MarkerTimings);
        const { tbResultsFolder } = flags;
        const filter = utils_1.collect(flags.filter, []);
        const traceFrame = flags.traceFrame ? flags.traceFrame : flags.url;
        const traceJSON = path.join(tbResultsFolder, 'trace.json');
        let frame = null;
        let startTime = -1;
        let rawTraceData = null;
        let trace = null;
        if (!traceFrame) {
            this.error(`Either a traceFrame or url are required flags.`);
        }
        try {
            rawTraceData = JSON.parse(fs.readFileSync(traceJSON, 'utf8'));
        }
        catch (error) {
            this.error(`Could not extract trace events from '${traceJSON}', ${error}`);
        }
        try {
            trace = utils_1.loadTraceFile(rawTraceData);
        }
        catch (error) {
            this.error(`${error}`);
        }
        if (traceFrame.startsWith('http')) {
            frame = utils_1.findFrame(trace, traceFrame);
        }
        else {
            frame = traceFrame;
        }
        if (!frame) {
            this.error(`frame not found`);
        }
        trace
            .filter((event) => utils_1.isMark(event) || utils_1.isCommitLoad(event))
            .sort(utils_1.byTime)
            .forEach((event) => {
            if (utils_1.isFrameNavigationStart(frame, event)) {
                startTime = event.ts;
                this.log(`Marker Timings: ${utils_1.format(event.ts, startTime)} ${event.name}`);
            }
            else if (utils_1.isFrameMark(frame, event)) {
                if (startTime === -1) {
                    startTime = event.ts;
                }
                this.log(`Marker Timings: ${utils_1.format(event.ts, startTime)} ${event.name}`);
            }
            else if (utils_1.isUserMark(event)) {
                if (filter.length === 0 ||
                    filter.some((f) => event.name.indexOf(f) !== -1)) {
                    this.log(`Marker Timings: ${utils_1.format(event.ts, startTime)} ${event.name}`);
                }
            }
            else if (utils_1.isCommitLoad(event)) {
                const { data } = event.args;
                if (data.frame === frame) {
                    this.log(`Marker Timings: ${utils_1.format(event.ts, startTime)} ${event.name} ${data.frame} ${data.url}`);
                }
            }
        });
    }
}
exports.default = MarkerTimings;
MarkerTimings.description = 'Get list of all user-timings from trace';
MarkerTimings.flags = {
    tbResultsFolder: flags_1.tbResultsFolder({ required: true }),
    filter: flags_1.filter(),
    url: flags_1.url({ required: true }),
    traceFrame: flags_1.traceFrame(),
};
//# sourceMappingURL=marker-timings.js.map